# Data analysis for Williams, S.T., Williams, K.S., Lewis, B.P. and Hill, R.A. (2017) Population dynamics and threats to an apex predator outside protected areas: Implications for carnivore management. Royal Society Open Science. 

# Code prepared by Sam Williams (samual.t.williams@gmail.com)

###########
### Figures
###########

rm(list=ls())

library(dplyr)
library(ggplot2)
library(extrafont)
library(scales)

# Figure 2. Sampling periods in which individual leopards were photographed on camera traps in the Soutpansberg Mountains between 2012 and 2016 (see Table A2 for dates). 

heatmapDF <- read.csv("heatmapLeopard.csv")

p <- ggplot(heatmapDF, aes(x=period, y=leopardID, fill=asc)) +
        scale_y_discrete(limits=c("SA21","SA20","SA19","SA18","SA17","AF28","AF27","AM16","AM15","SA16","AF26","SA15","SA14","AM14","AM13","SA13","SA12","AM12","AF25","AM11","AF24","AF23","AM10","AF22","SA11","SA10","SA09","AM09","SA08","AF21","AF20","AF19","AF18","AF17","AM08","AF16","AF15","AF14","AM07","AF13","SA07","AF12","AF11","SA06","SA05","AF10","SA04","AF09","AM06","SA03","AM05","AM04","SA02","AF07","AF06","AM03","AF05","AM02","AF04","AF03","AM01","AF02","SA01","AF01"))
p <- p + geom_tile() + 
        labs(x="Sampling period",y="Individual") + 
        theme_bw() +
        theme(text=element_text(family="Helvetica", size=7), legend.position=c(.1,.13), legend.background = NULL, axis.text.y=element_text(angle=0, hjust=1, size=7), legend.text=element_text(size=6), legend.title=element_text(size=6)) + 
        guides(fill=guide_legend(title="Age sex class")) #+
p

ggsave("Fig. 2.pdf", width=190, height=150, units="mm")

###

# Figure 3. Change in number of individual leopards identified per sampling period in each age sex class in the Soutpansberg Mountains between 2012 and 2016. Shading represents 95% confidence intervals.

individuals <- read.csv("individuals.csv")
individualsNoTotal <- filter(individuals, excludeTotal=="Yes")
individualsNoTotal$date <- as.Date(individualsNoTotal$date)

p <- ggplot(individualsNoTotal, aes(x=date, y=numberOfIndividuals, shape=asc)) +
        geom_smooth(method = lm, aes(colour=asc), size=0.3) +
        geom_point(aes(fill=asc), 
                   colour="black",pch=21, size=1.5, stroke=0.1, alpha=1) +
        theme_bw() +
        labs(x = "Year", y = "Number of individuals", colour="Age sex class", fill="Age sex class") +
        theme(text=element_text(family="Helvetica", size=8), legend.background = NULL, legend.text=element_text(size=7), legend.title=element_text(size=7), legend.position="bottom") +
        guides(colour = guide_legend(override.aes = list(size=1))) +
        scale_linetype_discrete(name="Age sex class ")
p

ggsave("Fig. 3.pdf", width=90, height=80, units="mm")


###

# Figure 4. Change in the population density of leopards in the Soutpansberg Mountains between 2008 and 2016. Shading represents 95% confidence intervals.

mydf <- read.csv("densityInclExcl2008.csv") # reads in data
mydf$date <- as.Date(mydf$date) # Formats date properly

dateVec<-seq(from=as.Date("2008-05-01"), to=as.Date("2016-03-01"), by="days")

p <- ggplot(mydf, aes(x=date, y=density)) +
        # geom_errorbar(aes(ymax = mydf$upperHPD, ymin=mydf$lowerHPD), width=30, size=0.2, colour="grey") +
        geom_smooth(method = lm, se=TRUE, size=0.3, aes(colour=InclExcl)) +
        geom_point(size=0.5, aes(colour=InclExcl)) +
        labs(x = "Year", y = "Population density (animals per 100 km²)", colour="Data set") +
        theme_bw() +
        theme(text=element_text(family="Helvetica", size=8),legend.position="bottom", legend.background = NULL, legend.title=element_text(size=6), legend.text=element_text(size=6), legend.key.size=unit(1, "mm")) +
        scale_x_date(labels = date_format("%Y"), limits=c(min(dateVec), max=max(dateVec)), date_breaks = "1 year")
p 

ggsave("Fig. 4.pdf", width=90, height=80, units="mm")


#####################################################################################


##########
# Analysis
##########

# Test for difference in the number of sampling periods for which adult males and adult females remained present 
tenure <- read.csv("leopardTenure.csv")
wilcox.test(tenure ~ asc, data = tenure, paired = FALSE, exact = FALSE)

###


# Linear regression of date against number of individuals of each age sex class per sampling period

individuals <- read.csv("individuals.csv")
individuals$date <- as.Date(individuals$date)


# linear regression adult males against date
# Import data
individualsAM <- filter(individuals, asc=="Adult male")
modelAM <- lm(numberOfIndividuals ~ date, data = individualsAM) 
summary(modelAM)


# linear regression of number of adult females against date
individualsAF <- filter(individuals, asc=="Adult female")
modelAF <- lm(numberOfIndividuals ~ date, data = individualsAF)
summary(modelAF)


# Linear regression of number of sub-adults against date
individualsCub <- filter(individuals, asc=="Sub-adult")
modelCub <- lm(numberOfIndividuals ~ date, data = individualsCub)
summary(modelCub)


# Linear regression of total individuals against date
individualsTotal <- filter(individuals, asc=="Total")
modelTotal <- lm(numberOfIndividuals ~ date, data = individualsTotal)
summary(modelTotal)


###

# Linear regression of density against date 
# Import data
densityData <- read.csv("densityInclExcl2008.csv")
densityData$date <- as.Date(densityData$date)

# Linear regression of density against date excluding 2008 estimate
densityExcl2008 <- filter(densityData, InclExcl == "This study")
lmExcl2008 <- lm(density ~ date, data = densityExcl2008)
summary(lmExcl2008)

# Linear regression of density against date including 2008 estimate
densityIncl2008 <- filter(densityData, InclExcl == "This study plus [35]")
lmIncl2008 <- lm(density ~ date, data = densityIncl2008)
summary(lmIncl2008)
